@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class AllocationType
-  {
-    NOT_SET,
-    used,
-    future
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class AllocationType { NOT_SET, used, future };
 
-namespace AllocationTypeMapper
-{
+namespace AllocationTypeMapper {
 AWS_EC2_API AllocationType GetAllocationTypeForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForAllocationType(AllocationType value);
-} // namespace AllocationTypeMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace AllocationTypeMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
