@@ -87,6 +87,22 @@ class AttachVolumeResponse {
   }
   ///@}
 
+  ///@{
+  /**
+   * <p>The index of the EBS card. Some instance types support multiple EBS cards.
+   * The default EBS card index is 0.</p>
+   */
+  inline int GetEbsCardIndex() const { return m_ebsCardIndex; }
+  inline void SetEbsCardIndex(int value) {
+    m_ebsCardIndexHasBeenSet = true;
+    m_ebsCardIndex = value;
+  }
+  inline AttachVolumeResponse& WithEbsCardIndex(int value) {
+    SetEbsCardIndex(value);
+    return *this;
+  }
+  ///@}
+
   ///@{
   /**
    * <p>The ID of the volume.</p>
@@ -193,6 +209,8 @@ class AttachVolumeResponse {
 
   Aws::String m_instanceOwningService;
 
+  int m_ebsCardIndex{0};
+
   Aws::String m_volumeId;
 
   Aws::String m_instanceId;
@@ -207,6 +225,7 @@ class AttachVolumeResponse {
   bool m_deleteOnTerminationHasBeenSet = false;
   bool m_associatedResourceHasBeenSet = false;
   bool m_instanceOwningServiceHasBeenSet = false;
+  bool m_ebsCardIndexHasBeenSet = false;
   bool m_volumeIdHasBeenSet = false;
   bool m_instanceIdHasBeenSet = false;
   bool m_deviceHasBeenSet = false;
