@@ -7,6 +7,7 @@
 #include <aws/core/utils/memory/stl/AWSStreamFwd.h>
 #include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/ec2/model/AmdSevSnpSpecification.h>
+#include <aws/ec2/model/NestedVirtualizationSpecification.h>
 
 #include <utility>
 
@@ -86,15 +87,37 @@ class CpuOptionsRequest {
     return *this;
   }
   ///@}
+
+  ///@{
+  /**
+   * <p>Indicates whether to enable the instance for nested virtualization. Nested
+   * virtualization is supported only on 8th generation Intel-based instance types
+   * (c8i, m8i, r8i, and their flex variants). When nested virtualization is enabled,
+   * Virtual Secure Mode (VSM) is automatically disabled for the instance.</p>
+   */
+  inline NestedVirtualizationSpecification GetNestedVirtualization() const { return m_nestedVirtualization; }
+  inline bool NestedVirtualizationHasBeenSet() const { return m_nestedVirtualizationHasBeenSet; }
+  inline void SetNestedVirtualization(NestedVirtualizationSpecification value) {
+    m_nestedVirtualizationHasBeenSet = true;
+    m_nestedVirtualization = value;
+  }
+  inline CpuOptionsRequest& WithNestedVirtualization(NestedVirtualizationSpecification value) {
+    SetNestedVirtualization(value);
+    return *this;
+  }
+  ///@}
  private:
   int m_coreCount{0};
 
   int m_threadsPerCore{0};
 
   AmdSevSnpSpecification m_amdSevSnp{AmdSevSnpSpecification::NOT_SET};
+
+  NestedVirtualizationSpecification m_nestedVirtualization{NestedVirtualizationSpecification::NOT_SET};
   bool m_coreCountHasBeenSet = false;
   bool m_threadsPerCoreHasBeenSet = false;
   bool m_amdSevSnpHasBeenSet = false;
+  bool m_nestedVirtualizationHasBeenSet = false;
 };
 
 }  // namespace Model
