@@ -102,7 +102,10 @@ class FleetLaunchTemplateOverrides {
 
   ///@{
   /**
-   * <p>The Availability Zone in which to launch the instances.</p>
+   * <p>The Availability Zone in which to launch the instances. For example,
+   * <code>us-east-2a</code>.</p> <p>Either <code>AvailabilityZone</code> or
+   * <code>AvailabilityZoneId</code> must be specified in the request, but not
+   * both.</p>
    */
   inline const Aws::String& GetAvailabilityZone() const { return m_availabilityZone; }
   inline bool AvailabilityZoneHasBeenSet() const { return m_availabilityZoneHasBeenSet; }
@@ -274,6 +277,27 @@ class FleetLaunchTemplateOverrides {
     return *this;
   }
   ///@}
+
+  ///@{
+  /**
+   * <p>The ID of the Availability Zone in which to launch the instances. For
+   * example, <code>use2-az1</code>.</p> <p>Either <code>AvailabilityZone</code> or
+   * <code>AvailabilityZoneId</code> must be specified in the request, but not
+   * both.</p>
+   */
+  inline const Aws::String& GetAvailabilityZoneId() const { return m_availabilityZoneId; }
+  inline bool AvailabilityZoneIdHasBeenSet() const { return m_availabilityZoneIdHasBeenSet; }
+  template <typename AvailabilityZoneIdT = Aws::String>
+  void SetAvailabilityZoneId(AvailabilityZoneIdT&& value) {
+    m_availabilityZoneIdHasBeenSet = true;
+    m_availabilityZoneId = std::forward<AvailabilityZoneIdT>(value);
+  }
+  template <typename AvailabilityZoneIdT = Aws::String>
+  FleetLaunchTemplateOverrides& WithAvailabilityZoneId(AvailabilityZoneIdT&& value) {
+    SetAvailabilityZoneId(std::forward<AvailabilityZoneIdT>(value));
+    return *this;
+  }
+  ///@}
  private:
   InstanceType m_instanceType{InstanceType::NOT_SET};
 
@@ -294,6 +318,8 @@ class FleetLaunchTemplateOverrides {
   Aws::String m_imageId;
 
   Aws::Vector<BlockDeviceMappingResponse> m_blockDeviceMappings;
+
+  Aws::String m_availabilityZoneId;
   bool m_instanceTypeHasBeenSet = false;
   bool m_maxPriceHasBeenSet = false;
   bool m_subnetIdHasBeenSet = false;
@@ -304,6 +330,7 @@ class FleetLaunchTemplateOverrides {
   bool m_instanceRequirementsHasBeenSet = false;
   bool m_imageIdHasBeenSet = false;
   bool m_blockDeviceMappingsHasBeenSet = false;
+  bool m_availabilityZoneIdHasBeenSet = false;
 };
 
 }  // namespace Model
