@@ -4,27 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class ProtocolValue
-  {
-    NOT_SET,
-    gre
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class ProtocolValue { NOT_SET, gre };
 
-namespace ProtocolValueMapper
-{
+namespace ProtocolValueMapper {
 AWS_EC2_API ProtocolValue GetProtocolValueForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForProtocolValue(ProtocolValue value);
-} // namespace ProtocolValueMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace ProtocolValueMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
