@@ -4,27 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class Schedule
-  {
-    NOT_SET,
-    hourly
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class Schedule { NOT_SET, hourly };
 
-namespace ScheduleMapper
-{
+namespace ScheduleMapper {
 AWS_EC2_API Schedule GetScheduleForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForSchedule(Schedule value);
-} // namespace ScheduleMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace ScheduleMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
